body{
 margin:10px;
 font-size: 1.0em;word-wrap:break-word;
}
ul,li{list-style-type:none;margin:0;padding:0;}

p{text-indent:2em; line-height:1.5em; margin-top:0; margin-bottom:0.5em;}

.catalog{line-height: 3.5em;height: 3.5em;font-size: 0.8em;}
li{border-bottom: 1px solid #D5D5D5;}
h1{font-size:1.6em; font-weight:bold;}

h2 {
    display: block;
    font-size: 1.2em;
    font-weight: bold;
    margin-bottom: 0.83em;
    margin-left: 0;
    margin-right: 0;
    margin-top: 1em;
}

.mbppagebreak {
    display: block;
    margin-bottom: 0;
    margin-left: 0;
    margin-right: 0;
    margin-top: 0 }
a {
    color: inherit;
    text-decoration: none;
    cursor: default
    }
a[href] {
    color: blue;
    text-decoration: none;
    cursor: pointer
    }

.italic {
    font-style: italic
    }
